@@ -6,12 +6,12 @@ use swc_common::{util::take::Take, Spanned, SyntaxContext, DUMMY_SP};
 use swc_ecma_ast::*;
 use swc_ecma_utils::{ident::IdentLike, undefined, ExprExt, Value::Known};
 
-/// Methods related to the option `evaludate`.
+/// Methods related to the option `evaluate`.
 impl<M> Optimizer<'_, M>
 where
     M: Mode,
 {
-    /// Evaludate expression if possible.
+    /// Evaluate expression if possible.
     ///
     /// This method call apppropriate methods for each ast types.
     pub(super) fn evaluate(&mut self, e: &mut Expr) {
@@ -391,7 +391,7 @@ where
                             }
                             (FpCategory::Normal, FpCategory::Zero) => {
                                 self.changed = true;
-                                tracing::debug!("evaluate: `constant / 0` => `Infinity`");
+                                tracing::debug!("evaluate: `{} / 0` => `Infinity`", ln);
 
                                 // Sign does not matter for NaN
                                 *e = if ln.is_sign_positive() == rn.is_sign_positive() {
@@ -404,7 +404,7 @@ where
                                         span: bin.span,
                                         op: op!(unary, "-"),
                                         arg: Box::new(Expr::Ident(Ident::new(
-                                            js_word!("NaN"),
+                                            js_word!("Infinity"),
                                             bin.span.with_ctxt(SyntaxContext::empty()),
                                         ))),
                                     })
